# remirepo/fedora spec file for php-tecnickcom-tc-lib-unicode-data
#
# Copyright (c) 2015-2024 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global gh_commit    c25c8149c902ab0beb7b0b8851f982bc9a518f95
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global c_vendor     tecnickcom
%global gh_owner     tecnickcom
%global gh_project   tc-lib-unicode-data
%global php_project  %{_datadir}/php/Com/Tecnick/Unicode/Data
%global with_tests   0%{!?_without_tests:1}

Name:           php-%{gh_owner}-%{gh_project}
Version:        2.0.14
Release:        1%{?dist}
Summary:        PHP library containing UTF-8 font definitions

License:        LGPL-3.0-or-later
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{name}-%{version}-%{?gh_short}.tar.gz

BuildArch:      noarch
%if %{with_tests}
# For tests
%global phpunit %{_bindir}/phpunit10
BuildRequires:  phpunit10 >= 10.1.2
BuildRequires:  php(language) >= 8.0
%endif
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#        "php": ">=8.0"
Requires:       php(language) >= 8.0
# From phpcompatinfo report for version 1.1.1
# Only Core
Requires:       php-composer(fedora/autoloader)

# Library renamed (not provided as not compatible)
Obsoletes:      php-tecnickcom-tc-lib-pdf-font-data < 1.2
# Composer
Provides:       php-composer(%{c_vendor}/%{gh_project}) = %{version}
# Upstream package name
Provides:       php-%{gh_project} = %{version}


%description
PHP library containing UTF-8 font definitions.

The initial source code has been extracted from TCPDF (http://www.tcpdf.org).


%prep
%setup -q -n %{gh_project}-%{gh_commit}

# See https://github.com/tecnickcom/tc-lib-unicode-data/issues/3
: Sanity check
grep -q '^%{version}$' VERSION


%build
phpab --template fedora --output src/autoload.php src


%install
mkdir -p   $(dirname %{buildroot}%{php_project})
cp -pr src %{buildroot}%{php_project}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require '%{buildroot}%{php_project}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Test\\', dirname(__DIR__) . '/test');
EOF

ret=0
for cmdarg in php php81 php82 php83 php84; do
   if which $cmdarg; then
      set $cmdarg
      cp phpunit.xml.dist phpunit.xml
      $1 ${2:-%{phpunit}} --migrate-configuration || :
      $1 ${2:-%{phpunit}} --no-coverage || ret=1
   fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%license LICENSE
%doc composer.json
%doc *.md
%dir %{_datadir}/php/Com
%dir %{_datadir}/php/Com/Tecnick
%dir %{_datadir}/php/Com/Tecnick/Unicode
%{php_project}


%changelog
* Mon Sep  9 2024 Remi Collet <remi@remirepo.net> - 2.0.14-1
- update to 2.0.14 (no change)

* Mon Aug 19 2024 Remi Collet <remi@remirepo.net> - 2.0.13-1
- update to 2.0.13 (no change)

* Fri Apr 12 2024 Remi Collet <remi@remirepo.net> - 2.0.11-1
- update to 2.0.11

* Wed Nov 29 2023 Remi Collet <remi@remirepo.net> - 2.0.10-1
- update to 2.0.10 (no change)

* Tue Nov 28 2023 Remi Collet <remi@remirepo.net> - 2.0.8-1
- update to 2.0.8 (no change)

* Wed Nov 22 2023 Remi Collet <remi@remirepo.net> - 2.0.7-1
- update to 2.0.7
- raise dependency on PHP 8

* Mon Oct 23 2023 Remi Collet <remi@remirepo.net> - 1.7.33-1
- update to 1.7.33 (no change)

* Thu Oct 12 2023 Remi Collet <remi@remirepo.net> - 1.7.31-1
- update to 1.7.31

* Tue Oct 10 2023 Remi Collet <remi@remirepo.net> - 1.7.26-1
- update to 1.7.26

* Tue Oct 10 2023 Remi Collet <remi@remirepo.net> - 1.7.23-1
- update to 1.7.23

* Fri Sep  8 2023 Remi Collet <remi@remirepo.net> - 1.7.22-1
- update to 1.7.22 (no change)

* Wed May 24 2023 Remi Collet <remi@remirepo.net> - 1.7.18-1
- update to 1.7.18 (no change)

* Fri May  5 2023 Remi Collet <remi@remirepo.net> - 1.7.17-1
- update to 1.7.17 (no change)

* Thu May  4 2023 Remi Collet <remi@remirepo.net> - 1.7.15-1
- update to 1.7.15 (no change)

* Wed May  3 2023 Remi Collet <remi@remirepo.net> - 1.7.13-1
- update to 1.7.13 (no change)

* Thu Dec 22 2022 Remi Collet <remi@remirepo.net> - 1.7.12-1
- update to 1.7.12 (no change)

* Tue Jun 14 2022 Remi Collet <remi@remirepo.net> - 1.7.8-1
- update to 1.7.8 (no change)

* Mon Jan  3 2022 Remi Collet <remi@remirepo.net> - 1.7.6-1
- update to 1.7.6 (no change)

* Mon Feb  8 2021 Remi Collet <remi@remirepo.net> - 1.7.3-1
- update to 1.7.3 (no change)

* Mon Dec 21 2020 Remi Collet <remi@remirepo.net> - 1.7.0-1
- update to 1.7.0
- switch to classmap autoloader

* Fri Jan  3 2020 Remi Collet <remi@remirepo.net> - 1.6.11-1
- update to 1.6.11 (no change)

* Thu Jan  2 2020 Remi Collet <remi@remirepo.net> - 1.6.10-1
- update to 1.6.10 (no change)

* Fri Sep 20 2019 Remi Collet <remi@remirepo.net> - 1.6.9-1
- update to 1.6.9 (no change)

* Mon Jun 25 2018 Remi Collet <remi@remirepo.net> - 1.6.8-1
- update to 1.6.8 (no change)

* Mon May 14 2018 Remi Collet <remi@remirepo.net> - 1.6.7-1
- update to 1.6.7 (no change)
- switch to phpunit7

* Tue Jan  2 2018 Remi Collet <remi@remirepo.net> - 1.6.6-1
- Update to 1.6.6 (no change)

* Sun Feb 12 2017 Remi Collet <remi@remirepo.net> - 1.6.5-1
- update to 1.6.5 (no change)

* Mon Feb  6 2017 Remi Collet <remi@remirepo.net> - 1.6.4-1
- update to 1.6.4 (no change)

* Fri Sep  2 2016 Remi Collet <remi@fedoraproject.org> - 1.6.3-1
- update to 1.6.3 (no change)

* Tue Jun 14 2016 Remi Collet <remi@fedoraproject.org> - 1.6.0-1
- update to 1.6.0 (no change)

* Fri Mar  4 2016 Remi Collet <remi@fedoraproject.org> - 1.5.1-1
- update to 1.5.1 (no change)

* Fri Dec 11 2015 Remi Collet <remi@fedoraproject.org> - 1.4.23-1
- update to 1.4.23 (no change)
- raise dependency on php >= 5.4

* Mon Dec  7 2015 Remi Collet <remi@fedoraproject.org> - 1.4.21-1
- update to 1.4.21 (no change)

* Thu Dec  3 2015 Remi Collet <remi@fedoraproject.org> - 1.4.19-1
- update to 1.4.19 (no change)

* Fri Nov 27 2015 Remi Collet <remi@fedoraproject.org> - 1.4.18-1
- update to 1.4.18 (no change)

* Wed Nov 25 2015 Remi Collet <remi@fedoraproject.org> - 1.4.17-1
- update to 1.4.17 (no change)

* Fri Nov 20 2015 Remi Collet <remi@fedoraproject.org> - 1.4.13-1
- update to 1.4.13 (no change)

* Fri Nov 20 2015 Remi Collet <remi@fedoraproject.org> - 1.4.10-1
- update to 1.4.10 (no change)

* Wed Nov 18 2015 Remi Collet <remi@fedoraproject.org> - 1.4.8-1
- update to 1.4.8 (no change)
- run test suite with both PHP 5 and 7 when available

* Tue Oct 20 2015 Remi Collet <remi@fedoraproject.org> - 1.4.7-1
- update to 1.4.7 (no change)

* Fri Sep 25 2015 Remi Collet <remi@fedoraproject.org> - 1.4.6-1
- update to 1.4.6 (no change)

* Sun Sep 13 2015 Remi Collet <remi@fedoraproject.org> - 1.4.3-1
- update to 1.4.3
- provide php-composer(tecnickcom/tc-lib-unicode-data)

* Sat Aug  8 2015 Remi Collet <remi@fedoraproject.org> - 1.4.2-1
- update to 1.4.2

* Thu Aug  6 2015 Remi Collet <remi@fedoraproject.org> - 1.4.1-1
- update to 1.4.1

* Tue Aug  4 2015 Remi Collet <remi@fedoraproject.org> - 1.3.0-1
- update to 1.3.0

* Tue Aug  4 2015 Remi Collet <remi@fedoraproject.org> - 1.2.2-1
- update to 1.2.2

* Mon Aug  3 2015 Remi Collet <remi@fedoraproject.org> - 1.2.1-1
- update to 1.2.1 (no change)

* Mon Aug  3 2015 Remi Collet <remi@fedoraproject.org> - 1.2.0-1
- renamed from pdf-font-data to unicode-data

* Mon Aug  3 2015 Remi Collet <remi@fedoraproject.org> - 1.1.4-1
- update to 1.1.4

* Fri Jul 24 2015 Remi Collet <remi@fedoraproject.org> - 1.1.3-1
- update to 1.1.3 (no change)

* Thu Jul  2 2015 Remi Collet <remi@fedoraproject.org> - 1.1.1-1
- initial package, version 1.1.1

